%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 		  Lounis ADOUANE                                            %%
%% 		  Polytech'Clermont-Ferrand                                 %%
%%        Dpartement Gnie Electrique (GE3)                        %%
%% 		  Novembre 2006                                             %%
%% 		  Simulation d'un robot de type SCARA 2D.                   %%
%%        TP Modlisation et Commande des Robots (AURO11)           %%
%%                                                                  %%
%%  Gre tous les venement affectant la fenetre GUI (Graphical     %%
%%  User Interface)                                                 %%
%%  NB : cette fonction est appele par le programme                %%
%%  SimulationRobotSCARA.m.                                         %%
%%                                                                  %%
%%  Dernire mise  jour : Novembre 2010                            %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [] = GestionGUI(OP,action)

global PushBut1 PushBut2 PushBut3
global x1 y1 x2 y2
global theta1 theta2
global fig
global T
global r_last psi_last Down
global rmax rmin
global xi yi xf yf
global RadToDeg

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if OP<3 & action~=1
    set(PushBut1,'BackgroundColor',[0.8 0.8 0.8])
    set(PushBut2,'BackgroundColor',[0.8 0.8 0.8])
    set(PushBut3,'BackgroundColor',[0.8 0.8 0.8])
    set(gcf,'WindowButtonMotionFcn','')
    set(gcf,'WindowButtonDownFcn','')
    set(gcf,'WindowButtonUpFcn','')
end

%%%%%%%%%%%%%%%%%%
if OP==1		% Option 1 (Simulation sans Simulink)
    r=sqrt(x2^2+y2^2);
    psi=atan2(y2,x2);
    if action==0
        set(PushBut1,'BackgroundColor',[0.6 0.6 0.6]);
        %Initialisations ncessaires pour pouvoir utiliser la souris
        set(gcf,'WindowButtonDownFcn','GestionGUI(1,1)');
        set(gcf,'WindowButtonMotionFcn','');
        set(gcf,'WindowButtonUpFcn','');
        %% Mettre  jour les coordonnes du robot et l'afficher
        ModeleGeometriqueInverse([x2,y2]);
        ModeleGeometriqueDirect([theta1, theta2]);
        SetAffichage;
        %%
        set(gcf,'WindowButtonDownFcn','GestionGUI(1,1)')
        r_last=r;
        psi_last=psi;
    else
        step=40; % Nombre d'incrment entre la position initiale du robot et la position qu'il doit atteindre,
        % cette position finale est donne en utilisant la souris.
        cp=get(gca,'CurrentPoint');
        set(gcf,'WindowButtonDownFcn','')
        x=cp(1,1);
        y=cp(1,2);
        r=sqrt(x^2+y^2);
        psi=atan2(y,x);
        if r<=rmax & r>=rmin & psi>=0 & psi<=pi
            FLIP=sign((psi-pi/2)*(psi_last-pi/2));	%Valeur ngative si le robot doit tourner
            if FLIP==1;
                Dr=(r-r_last)/step;
                Dpsi=(psi-psi_last)/step;
                for k=1:step;                       %Animation du robot de sa position courante vers une position finale (consigne)
                    x=(r_last+k*Dr)*cos(psi_last+k*Dpsi);
                    y=(r_last+k*Dr)*sin(psi_last+k*Dpsi);
                    ModeleGeometriqueInverse([x,y]);
                    ModeleGeometriqueDirect([theta1, theta2]);
                    SetAffichage;
                end
            else
                theta1_last=theta1;
                theta2_last=theta2;

                ModeleGeometriqueInverse([r*cos(psi),r*sin(psi)]);

                theta1_goal=theta1;
                theta2_goal=theta2;

                Deltatheta1=(theta1_goal-theta1_last)/step;
                Deltatheta2=(theta2_goal-theta2_last)/step;

                for n=1:step;
                    theta1=theta1_last+n*Deltatheta1;
                    theta2=theta2_last+n*Deltatheta2;
                    ModeleGeometriqueDirect([theta1, theta2]);
                    SetAffichage;
                end
            end
            r_last=r;
            psi_last=psi;
        end
        set(gcf,'WindowButtonDownFcn','GestionGUI(1,1)');
    end

elseif OP==2  % Option 2, Simulation avec Simulink

    if action==0
        set(PushBut2,'BackgroundColor',[0.6 0.6 0.6])
        set(gcf,'WindowButtonDownFcn','GestionGUI(2,1)');
        set(gcf,'WindowButtonMotionFcn','');
        set(gcf,'WindowButtonUpFcn','');
        set(gcf,'WindowButtonDownFcn','GestionGUI(2,1)');
    else
        cp=get(gca,'CurrentPoint');
        set(gcf,'WindowButtonDownFcn','')

        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %Caractristiques de la trajectoire  suivre par l'effecteur du robot%
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        xi=x2; yi=y2;           %Position initiale de l'effecteur
        xf=cp(1,1); yf=cp(1,2); %Position finale dsire de l'effecteur

        %Vrification que la position dsire est bien  l'intrieur de
        %l'espace de travail du robot avant de lancer la simulation sous Simulink.
        r=sqrt(xf^2+yf^2);
        psi=atan2(yf,xf);
        if r<=rmax & r>=rmin & psi>=0 & psi<=pi
            T=20; % Priode ncessaire pour la simulation
            sim('SimulinkControleRobotScara_SansMD',[0 T]);
        end
        %%
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %%Dessin des caractristiques de la simulation effectue (Uniquement avec le modle SimulinkControleRobotScara_AvecMD.mdl)%
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%        
        %%% Dbut code affichage figure %%%
%         figure(2),
%         subplot(421), plot(DS_Temps,DS_ThetaConsigne(:,1)*RadToDeg,'b',DS_Temps,DS_ThetaArticulations(:,1)*RadToDeg,'r'),grid;ylabel('q1r et q1 []'),
%         legend('q1r','q1');
%         subplot(422), plot(DS_Temps,(DS_ThetaConsigne(:,1)-DS_ThetaArticulations(:,1))*RadToDeg),grid; ylabel('Erreur / q1')
%         
%         subplot(423), plot(DS_Temps,DS_ThetaConsigne(:,2)*RadToDeg,'b',DS_Temps,DS_ThetaArticulations(:,2)*RadToDeg,'r'),grid;ylabel('q2r et q2 []'),
%         legend('q2r','q2');
%         subplot(424), plot(DS_Temps,(DS_ThetaConsigne(:,2)-DS_ThetaArticulations(:,2))*RadToDeg),grid; ylabel('Erreur / q2')
%         
%         subplot(425), plot(DS_PositionConsigne(:,1),DS_PositionConsigne(:,2),'b',DS_PositionEffecteur(:,1),DS_PositionEffecteur(:,2),'r'),
%         grid;xlabel('Positions consignes et effectives de l''effecteur'), legend('Pc','Pe');
%         
%         ErreurPositions= sqrt((DS_PositionConsigne(:,1)-DS_PositionEffecteur(:,1)).^2+(DS_PositionConsigne(:,2)-DS_PositionEffecteur(:,2)).^2);
%         subplot(426), plot(DS_Temps,ErreurPositions,'r'), grid;xlabel('Erreur de position de l''effecteur [cm]'),
%         %%% Fin code affichage figure %%%
        %%
        set(fig,'WindowButtonDownFcn','GestionGUI(2,1)')
    end
    
elseif OP==3
    disp(' Mettez l''Aide de votre programme ici.....');
    disp(' .....');
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%