%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 		  Lounis ADOUANE                                           %%
%% 		  Polytech'Clermont-Ferrand                                %%   
%%        Dpartement Gnie Electrique (GE3)                       %%
%% 		  Novembre 2006                                            %%
%% 		  Simulation d'un robot de type SCARA 2D.                  %%
%%        TP Modlisation et Commande des Robots (AURO11)          %% 
%%                                                                 %% 
%% Fonction qui dfinit le modle gomtrique direct d'un robot    %%
%% planaire 2ddl, i.e., les positions (xi,yi) des diffrentes      %%
%% articulations du robot en fonction de leurs coordonnes         %%
%% articulaires.                                                   %% 
%% NB : cette fonction est appele par le programme                %%  
%% SimulationRobotSCARA.m.                                         %%
%%                                                                 %%
%% Dernire mise  jour : Novembre 2010                            %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function PositionEffecteur = ModeleGeometriqueDirect(Theta)
global x1 y1 x2 y2
global l1 l2 
global DegToRad RadToDeg
global theta1 theta2
global theta1_old theta2_old
global L1 L2 Link1 Link2
global S1 S2 S3 S4 					

theta1 = Theta(1);
theta2 = Theta(2);

theta1_old = theta1; 
theta2_old = theta2;

x1 = l1*cos(theta1);
y1 = l1*sin(theta1);

x2 = x1 + l2*cos(theta1+theta2);
y2 = y1 + l2*sin(theta1+theta2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Tm1 = [ 	cos(theta1) 	-sin(theta1)		0		0	                   % Transformation du repre 0 vers le repre '1'
   		    sin(theta1)     cos(theta1) 		0		0
   			       0			  0			    1		0
         	       0			  0			    0		1 ];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Tm2 = [ 	cos(theta1+theta2) 	-sin(theta1+theta2)		0		l1*cos(theta1) % Transformation du repre 1 vers le repre '2'
   		    sin(theta1+theta2)   cos(theta1+theta2)	   	0		l1*sin(theta1)
   			           0			   0			    1		0
         	           0			   0			    0		1 ];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
L1=Tm1*Link1;
L2=Tm2*Link2;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
S1=['\theta_{1} = ' num2str(0.01*round(100*theta1)*RadToDeg,3) '^o'];
S2=['X_{T} =' num2str(0.01*round(100*x2),3) ''];
S3=['\theta_{2} = ' num2str(0.01*round(100*theta2)*RadToDeg,3) '^o'];
S4=['Y_{T} = ' num2str(0.01*round(100*y2),3) ''];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

PositionEffecteur = [x2 y2];
