%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 		  Lounis ADOUANE                                           %%
%% 		  Polytech'Clermont-Ferrand                                %%   
%%        Dpartement Gnie Electrique (GE3)                       %%
%% 		  Novembre 2006                                            %%
%% 		  Simulation d'un robot de type SCARA 2D.                  %%
%%        TP Modlisation et Commande des Robots (AURO11)          %%
%%                                                                 %% 
%% Fonction qui dfinit le modle gomtrique inverse d'un robot   %%
%% planaire 2ddl, i.e. permet d'obtenir les coordonnes            %%
%% articulaires du robot en fonction des configurations x,y        %%  
%% que fait l'effecteur du robot.                                  %%
%% NB : cette fonction est appele par le programme                %%  
%% SimulationRobotSCARA.m.                                         %%
%%                                                                 %%
%% Dernire mise  jour : Novembre 2010                            %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function Theta = ModeleGeometriqueInverse(Position)
global l1 l2 
global theta1 theta2

x = Position(1);
y = Position(2);

%Les consignes x et y de l'effecteur doivent imprativement etre 
%contenues dans "l'espace de travail" du robot 
if (((sqrt(x^2+y^2))>(l1+l2)) | (sqrt(x^2+y^2)<(l1-l2)) )
    warning(['Attention la consigne (x,y) est en d''hors de l''espace attiegnable par le robot']);
end 

%Approche gomtrique (ad hoc) pour le calcul du MGI
theta2 = acos((x^2+y^2-l1^2-l2^2)/(2*l1*l2));

alpha = atan2(y,x);
beta = acos((x^2+y^2+l1^2-l2^2)/(2*l1*sqrt(x^2+y^2)));

theta1 = alpha - beta;

Theta=[theta1 theta2];
