%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %  Lounis ADOUANE                                                                               %%
% %  Polytech'Clermont-Ferrand                                                                    %%   
% %  Dpartement Gnie Electrique (GE3)                                                           %%
% %                                                                                               %%                                                                                             %%
% %  TP Modlisation et Commande des Robots (AURO11)                                              %%
% %                                                                                               %%
% %  Les programmes fournis vous permettront de simuler statiquement (sans modle dynamique)      %%
% %  et dynamiquement un robot de type SACRA 2D avec deux articulations rotoides.                 %%
% %  Vous allez devoir exploiter ces programmes pour raliser votre TP o vous devez entre        %%
% %  autres programmer un asservissement appropri pour controler ce systme non linaire         %%        
% %                                                                                               %%
% %  Pour excuter ce programme :                                                                 %%                                           
% %   1) assurez-vous que SimulationRobotSCARA.m, ModeleGeometriqueDirect.m,                      %% 
% %      ModeleGeometriqueInverse.m, GestionGUI.m, InitialisationAffichage.p, SetAffichage.p,     %%
% %      TrajectoireConsigne.m et SimulinkControleRobotSCARA_SansMD.mdl sont bien dans            %%
% %      le rpertoire courant de MATLAB,                                                         %%
% %   2) excutez le programme SimulationRobotSCARA.m,                                            %%
% %   3) cliquez sur l'un des boutons poussoirs pour excuter l'option approprie.                %%
% %                                                                                               %%
% %  SimulationRobotSCARA.m       C'est le programme principal (amorce)                           %%
% %  ModeleGeometriqueDirect.m    Dfinit les positions (xi,yi) des diffrentes articulations     %%
% %                               en fonction de leurs coordonnes articulaires                   %%
% %  ModeleGeometriqueInverse.m   Dfinit les coordonnes articulaires du robot en fonction       %%
% %                               de la position de l'effecteur                                   %%
% %  GestionGUI.m                 Gre tous les vnement affectant lafenetre GUI (Graphical      %%
% %                               User Interface)                                                 %%
% %  InitialisationAffichage.p    Permet d'initialiser l'affichage du simulateur                  %%
% %  SetAffichage.p               Permet de remettre  jour la reprsentation graphique du robot  %%
% %                               SCARA ainsi que l'affichage des informations articulaires et la %%
% %                               position de l'effecteur                                         %%                   
% %  TrajectoireConsigne.m        Donne la trajectoire consigne  suivre par l'effecteur du robot %%
% %                               dans le dommaine oprationnel                                   %%
% %  SimulinkControleRobotSCARA_SansMD.mdl   Modle simulink pour raliser une interaction entre  %%
% %                                          MATLAB et Simulink du robot SCARA                    %% 
% %  Version : Novembre 2006                                                                      %%
% %  Dernire mise  jour : Novembre 2010                                                         %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clc, clear all, close all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Dfinition des variables globales%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global l1 l2 % Dimensions des bras
global x1 y1 x2 y2   % Positions oprationnelles des articulations respectives du robot
global theta1 theta2 % Angles respectifs des articulations du robot
global PushBut1 PushBut2 PushBut3 % Pointeurs sur les boutons poussoirs
global S1 S2 S3 S4 				% Pointeurs sur les chaines de caractres
global L1 L2 Link1 Link2		% Matrices pour dessiner le robot SCARA
global C1 C2     	  % Pointeurs pour dessiner des cercles sur les articulations
global J1 J2          % Pointeurs pour dessiner des "plus" sur les articulations
global dis            %	Pointeurs sur des textes  afficher
global pF1 pF2 		  % Pointeurs sur les objets  colorier
global rmax rmin      % Rayon max et rayon min atteignable par l'effecteur du robot 
global DegToRad RadToDeg % Les constantes
global fig % Pointeur sur la figure courante  
global T 
%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Dfinition des constantes%
%%%%%%%%%%%%%%%%%%%%%%%%%%%
DegToRad=pi/180;
RadToDeg=180/pi;

l1=8.625;				% Longueur du bras '1'
l2=6.125;	    		% Longueur du bras '2'

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Initialisation des variables (tat initial du robot) %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
theta1= 90*DegToRad;
theta2 = 90*DegToRad;

%% Dbut code PID %% 

%% Fin code PID %%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Initialisation de la fentre d'affichage :%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fig=gcf; % Rcupration du pointeur de la figure courante

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%Dfinition des boutons poussoirs %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
P1 = ['GestionGUI(1,0)'];
PushBut1=uicontrol(fig,'Style','pushbutton','Units','normalized', ...
   	'Position',[0.10 .02 0.17125 0.05],'string','Sans Simulink', ...
    'Callback',P1,'visible','on','BackgroundColor',[0.8 0.8 0.8]);

P2 = ['GestionGUI(2,0)'];	
PushBut2=uicontrol(fig,'Style','pushbutton','Units','normalized', ...
   	'Position',[0.30125 .02 0.17125 0.05],'string','Avec Simulink', ...
    'Callback',P2,'visible','on','BackgroundColor',[0.8 0.8 0.8]);

P3 = ['GestionGUI(3,0)'];	
PushBut3=uicontrol(fig,'Style','pushbutton','Units','normalized', ...
   	'Position',[0.5025 .02 0.17125 0.05],'string','Aide', ...
    'Callback',P3,'visible','on','BackgroundColor',[0.8 0.8 0.8]);  

P4 = ['close;'];	
PushBut4=uicontrol(fig,'Style','pushbutton','Units','normalized', ...
   	'Position',[0.70375 .02 0.17125 0.05],'string','Fermer', ...
    'Callback',P4,'visible','on','BackgroundColor',[0.8 0.8 0.8]);
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

InitialisationAffichage; %Fonction pour initialiser l'interface d'affichage

%%Dbut dfinition des obstacles%%
% angle=0:5:360;
% Xobs1=9+0.90*cos(angle*pi/180);
% Yobs1=10+0.90*sin(angle*pi/180);
% Obstacle1=fill(Xobs1,Yobs1,'r');	% Remplissage de l'obstacle 1
% 
% Xobs2=0.90*cos(angle*pi/180);
% Yobs2=12+0.90*sin(angle*pi/180);
% Obstacle2=fill(Xobs2,Yobs2,'r');	% Remplissage de l'obstacle 2
% 
% set(Obstacle1,'FaceColor',[.4 .4 .4]);
% set(Obstacle2,'FaceColor',[.8 .3 .3]);
%%Fin dfinition des obstacles%%
